import { ConsoleLogger, Injectable, Logger } from '@nestjs/common';
import util from 'util';
import csv_parse_raw from 'csv-parse';
import iconv from 'iconv-lite';

export type CsvParseOptions = csv_parse_raw.Options;

const parse_csv: (
  input: Buffer | string,
  options?: csv_parse_raw.Options,
) => Promise<any> = util.promisify(csv_parse_raw);

@Injectable()
export class CsvParseService extends ConsoleLogger {
  constructor() {
    super('csv');
  }
  public async parseCsv<
    T extends Record<string, string | number> | (string | number)[]
  >(
    buf: Buffer,
    encoding = 'utf8',
    options: CsvParseOptions = { columns: true, trim: true, cast: true },
  ): Promise<T[]> {
    try {
      const fileContent = iconv.decode(buf, encoding);
      const parsedData: T[] = await parse_csv(fileContent, {
        columns: true,
        trim: true,
        cast: true,
        ...options,
      });
      return parsedData;
    } catch (e) {
      this.error(`Failed to parse csv data: ${e.toString()}`);
      return [];
    }
  }
}
