import yaml from 'yaml';
import * as fs from 'fs';

export interface Workspace {
  title: string;
  encoding?: string;
  default?: boolean;
}

export interface Config {
  host: string;
  port: number;
  rootPath: string;
  workspaces: Record<string, Workspace>;
}

const defaultConfig: Config = {
  host: '::',
  port: 3000,
  rootPath: './data',
  workspaces: {},
};

export async function loadConfig(): Promise<Config> {
  let readConfig: Partial<Config> = {};
  try {
    const configText = await fs.promises.readFile('./config.yaml', 'utf-8');
    readConfig = yaml.parse(configText);
  } catch (e) {
    console.error(`Failed to read config: ${e.toString()}`);
  }
  return {
    ...defaultConfig,
    ...readConfig,
  };
}
