import { ConsoleLogger, Injectable } from '@nestjs/common';
import { ConfigService } from '@nestjs/config';
import { Workspace } from '../utility/config';

@Injectable()
export class WorkspaceService extends ConsoleLogger {
  private readonly workspaceMap: Map<string, Workspace>;
  private readonly defaultWorkspace: Workspace;
  constructor(private config: ConfigService) {
    super('workspace');
    const entries = Object.entries(
      this.config.get<Workspace>('workspaces'),
    ) as [string, Workspace][];
    this.workspaceMap = new Map(entries);
    const defaultEntry = entries.find((e) => e[1].default);
    if (defaultEntry) {
      this.defaultWorkspace = defaultEntry[1];
    }
  }

  getWorkspace(name?: string) {
    return name ? this.workspaceMap.get(name) : this.defaultWorkspace;
  }
}
